/*KSlacky InfoPkg is a package information tool that provide
the list of packages installe on your Slackware system
Copyright (C) 2008  Giovanni Santostefano

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.*/

#include <KLocale>
#include <KMessageBox>
#include <QDir>
#include <QStringList>
#include <QTextStream>

#include "mainwindow.h"

MainWindow::MainWindow(QMainWindow *parent)
: KMainWindow(parent)
{
	QMainWindow *wnd = new QMainWindow( this );
	ui.setupUi(wnd);
    connect( ui.pkglist, SIGNAL( itemSelectionChanged() ),
             this, SLOT( PackageListIndexChange() ) );
	connect( ui.aboutbutton, SIGNAL( clicked() ),
             this, SLOT( AboutButtonPressed() ) );
	connect( ui.exitbutton, SIGNAL( clicked() ),
             this, SLOT( ExitButtonPressed() ) );
    wnd->show();
}

MainWindow::~MainWindow()
{
}

void MainWindow::PKGLoading()
{
	QDir dirman=QDir("/var/log/packages");
	
	ui.lcdNumber->display((int)dirman.count());
	
	dirman.setFilter(QDir::Files | QDir::Hidden | QDir::NoSymLinks);
    dirman.setSorting(QDir::Name);

    QFileInfoList list = dirman.entryInfoList();
	
	for(int i=0; i<list.size(); ++i)
	{
		QFileInfo fileinfo = list.at(i);
		ui.pkglist->addItem(fileinfo.fileName());
	}
	
	ShowFileInfo(0);
}

void MainWindow::PackageListIndexChange()
{
	ShowFileInfo(ui.pkglist->currentRow());
}

void MainWindow::ExitButtonPressed()
{
	exit(0);
}

void MainWindow::AboutButtonPressed()
{
	KMessageBox::information( this, 
    i18n("KSlacky InfoPkg is a Slackware information tool\
    that shows info on installed packages\
    \nDeveloped by Giovanni Santostefano\
    \nhttp://santostefanogiovanni.blogspot.com" ),
                              i18n( "About KSlacky InfoPkg" ) );
}

void MainWindow::ShowFileInfo(int index)
{
	QString filepath="/var/log/packages/";
	filepath+=ui.pkglist->item(index)->text();
	
	//file opening and reading the content
	QFile file(filepath);
	file.open(QIODevice::ReadOnly);
	QString content=QTextStream(&file).readAll();
	
	//cut off the file list info
	QStringList liststrings = content.split("FILE LIST");
	if(liststrings.empty())
	{
		ui.pkgdesc->setPlainText("Can't retreive package informations");
		ui.pkgfiles->setPlainText("Can't retreive package file list");
	}
	else
	{
		ui.pkgdesc->setPlainText(liststrings.at(0));
		ui.pkgfiles->setPlainText(liststrings.at(1));
	}
}

#include "mainwindow.moc"
